

------------------
Correlated Dataset
------------------

The Core Scientific Dataset Model (CSDM) also support multiple dependent
variables that share the same `d`-dimensional coordinate grid, where
:math:`d>=0`.
We call the dependent variables from these datasets as `correlated datasets`.

In this section, we go over a few examples.

.. include:: 0D{1,1}-datasets.rst
.. include:: meteorological.rst
.. include:: eagle_nebula.rst
